==> huaweicloudsdkprojectman-3.0.46-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/list_project_demand_static_v4_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListProjectDemandStaticV4Response(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'demand_statistics': 'list[DemandStatisticResponseV4]'
    }

    attribute_map = {
        'demand_statistics': 'demand_statistics'
    }

    def __init__(self, demand_statistics=None):
        """ListProjectDemandStaticV4Response - a model defined in huaweicloud sdk"""
        
        super(ListProjectDemandStaticV4Response, self).__init__()

        self._demand_statistics = None
        self.discriminator = None

        if demand_statistics is not None:
            self.demand_statistics = demand_statistics

    @property
    def demand_statistics(self):
        """Gets the demand_statistics of this ListProjectDemandStaticV4Response.

        需求统计

        :return: The demand_statistics of this ListProjectDemandStaticV4Response.
        :rtype: list[DemandStatisticResponseV4]
        """
        return self._demand_statistics

    @demand_statistics.setter
    def demand_statistics(self, demand_statistics):
        """Sets the demand_statistics of this ListProjectDemandStaticV4Response.

        需求统计

        :param demand_statistics: The demand_statistics of this ListProjectDemandStaticV4Response.
        :type: list[DemandStatisticResponseV4]
        """
        self._demand_statistics = demand_statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProjectDemandStaticV4Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.51-py2.py3-none-any.whl: huaweicloudsdkprojectman/v4/model/list_project_demand_static_v4_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListProjectDemandStaticV4Response(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'demand_statistics': 'list[DemandStatisticResponseV4]'
    }

    attribute_map = {
        'demand_statistics': 'demand_statistics'
    }

    def __init__(self, demand_statistics=None):
        """ListProjectDemandStaticV4Response - a model defined in huaweicloud sdk"""
        
        super(ListProjectDemandStaticV4Response, self).__init__()

        self._demand_statistics = None
        self.discriminator = None

        if demand_statistics is not None:
            self.demand_statistics = demand_statistics

    @property
    def demand_statistics(self):
        """Gets the demand_statistics of this ListProjectDemandStaticV4Response.

        需求统计

        :return: The demand_statistics of this ListProjectDemandStaticV4Response.
        :rtype: list[DemandStatisticResponseV4]
        """
        return self._demand_statistics

    @demand_statistics.setter
    def demand_statistics(self, demand_statistics):
        """Sets the demand_statistics of this ListProjectDemandStaticV4Response.

        需求统计

        :param demand_statistics: The demand_statistics of this ListProjectDemandStaticV4Response.
        :type: list[DemandStatisticResponseV4]
        """
        self._demand_statistics = demand_statistics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListProjectDemandStaticV4Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
